@@ -1,6 +1,6 @@
 from time import sleep
 
-from ..r_algorithms import RAlgorithm
+from ..r_algorithm import RAlgorithm
 from ...database import DatabaseStatus
 from ...query import Query, Wait
 
